@@ -343,8 +343,26 @@ void MainWindow::applyAdd()
             tr("Password needs to be at least 2 characters long. Please enter a longer password before proceeding."));
         return;
     }
-    QProcess::execute("adduser",
-                      {"--disabled-login", "--force-badname", "--gecos", userNameEdit->text(), userNameEdit->text()});
+
+    QString cmd;
+    cmd = QStringLiteral("sed -n '/^DSHELL=/{ s///; s:^/bin/:/usr/bin/:; h}; ${x; p}' /etc/adduser.conf");
+    QString dshell = shell->getCmdOut(cmd, true).trimmed();
+    if (!QFile::exists(dshell))
+        dshell = "/usr/bin/bash";
+
+    cmd = QStringLiteral("LC_ALL=C adduser --help 2>/dev/null | grep -m1 -o -- --comment | head -1");
+    QString commentOption = shell->getCmdOut(cmd, true).trimmed();
+    if (commentOption != QStringLiteral("--comment"))
+        commentOption = "--gecos";
+
+    cmd = QStringLiteral("LC_ALL=C adduser --help 2>/dev/null | grep -m1 -o -- --allow-bad-names | head -1");
+    QString allowBadNames = shell->getCmdOut(cmd, true).trimmed();
+    if (allowBadNames != QStringLiteral("--allow-bad-names"))
+        allowBadNames = QStringLiteral("--force-badname");
+
+    QProcess::execute("adduser", {"--disabled-login", allowBadNames, "--shell", dshell,
+                                  commentOption, userNameEdit->text(), userNameEdit->text()});
+
     QProcess proc;
     proc.start(QStringLiteral("passwd"), QStringList {userNameEdit->text()}, QIODevice::ReadWrite);
     proc.waitForStarted();
@@ -397,7 +415,7 @@ void MainWindow::applyDelete()
     if (QMessageBox::Yes == QMessageBox::warning(this, windowTitle(), msg, QMessageBox::Yes, QMessageBox::No)) {
         if (deleteHomeCheckBox->isChecked()) {
             QProcess::execute("killall", {"-u", comboDeleteUser->currentText()});
-            cmd = QStringLiteral("deluser --force --remove-home %1").arg(comboDeleteUser->currentText());
+            cmd = QStringLiteral("deluser --remove-home %1").arg(comboDeleteUser->currentText());
         } else {
             cmd = QStringLiteral("deluser %1").arg(comboDeleteUser->currentText());
         }
